@@ -3,7 +3,7 @@
 
 package HiD::Role::IsConverted;
 our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Role::IsConverted::VERSION = '1.991';
+$HiD::Role::IsConverted::VERSION = '1.992';
 use Moose::Role;
 use namespace::autoclean;
 
@@ -47,7 +47,7 @@ has converted_content => (
       );
     }
 
-    return _convert_by_extension( $content , $self->ext );
+    return $self->convert_by_extension($content);
   }
 );
 
@@ -59,7 +59,8 @@ has converted_excerpt => (
   default => sub {
     my $self = shift;
 
-    my $converted_excerpt = _convert_by_extension( $self->excerpt , $self->ext );
+    my $converted_excerpt = $self->convert_by_extension(
+        $self->excerpt );
 
     if ( $self->excerpt ne $self->content ) {
       # Add the "read more" link
@@ -177,6 +178,23 @@ has template_data_without_content => (
   },
 );
 
+
+has extension_processors => (
+    is => 'ro',
+    isa => 'HashRef',
+    lazy => 1,
+    default => sub {
+        return $_[0]->get_config('extension_processors') || {
+            markdown => [ 'Text::Markdown'      , 'markdown' ] ,
+            mkdn     => [ 'Text::Markdown'      , 'markdown' ] ,
+            mk       => [ 'Text::Markdown'      , 'markdown' ] ,
+            md       => [ 'Text::Markdown'      , 'markdown' ] ,
+            mmd      => [ 'Text::MultiMarkdown' , 'markdown' ] ,
+            textile  => [ 'Text::Textile'       , 'process'  ] ,
+        }
+    }
+);
+
 around BUILDARGS => sub {
   my $orig  = shift;
   my $class = shift;
@@ -206,30 +224,20 @@ around BUILDARGS => sub {
   return $class->$orig( \%args );
 };
 
-{ # hide the map
 
-  ### FIXME make this extensible
-  my %conversion_extension_map = (
-    markdown => [ 'Text::Markdown'      , 'markdown' ] ,
-    mkdn     => [ 'Text::Markdown'      , 'markdown' ] ,
-    mk       => [ 'Text::Markdown'      , 'markdown' ] ,
-    md       => [ 'Text::Markdown'      , 'markdown' ] ,
-    mmd      => [ 'Text::MultiMarkdown' , 'markdown' ] ,
-    textile  => [ 'Text::Textile'       , 'process'  ] ,
-  );
 
-  sub _convert_by_extension {
-    my( $content , $extension ) = @_;
 
-    return $content
-      unless exists $conversion_extension_map{ $extension };
+sub convert_by_extension {
+    my ( $self, $content ) = @_;
 
-    my( $module , $method ) = @{ $conversion_extension_map{ $extension }};
+
+    my $converter = $self->extension_processors->{ $self->ext }
+        or return $content;
+
+    my( $module , $method ) = @$converter;
     load_class( $module );
 
-    my $converted = $module->new->$method( $content );
-    return $converted;
-  }
+    return $module->new->$method( $content );
 }
 
 no Moose::Role;
@@ -311,9 +319,33 @@ Data for passing to template processing function.
 
 Data for passing to template processing function when processing things that will _be_ content (e.g., blog posts).
 
+=head2 extension_processors
+
+An hash mapping file extensions to the module/method pair to use to
+convert the entry into HTML. Can be set via the C<extension_processors> key in
+the configuration file. If not provided, the default is:
+
+    {
+        markdown => [ 'Text::Markdown'      , 'markdown' ] ,
+        mkdn     => [ 'Text::Markdown'      , 'markdown' ] ,
+        mk       => [ 'Text::Markdown'      , 'markdown' ] ,
+        md       => [ 'Text::Markdown'      , 'markdown' ] ,
+        mmd      => [ 'Text::MultiMarkdown' , 'markdown' ] ,
+        textile  => [ 'Text::Textile'       , 'process'  ] ,
+    }
+
+=head1 METHODS
+
+=head2 convert_by_extension
+
+    $self->convert_by_extension( $content );
+
+Converts the provided content according to `$self->extension`, using
+the mappings in the `extension_processors` attribute.
+
 =head1 VERSION
 
-version 1.991
+version 1.992
 
 =head1 AUTHOR
 
